@@ -1,3 +1,4 @@
+# common way to print error messages
 errMsg <- function(x) {
   stop(sprintf("shinyjs: %s", x), call. = FALSE)
 }
@@ -14,6 +15,7 @@ getSession <- function() {
   session
 }
 
+# set up some javascript functions to work with shinyjs
 setupJS <- function(jsFuncs, script, text, ...) {
   # add a shiny message handler binding for each supported method
   tpl <- paste0(
@@ -27,7 +29,7 @@ setupJS <- function(jsFuncs, script, text, ...) {
 
   # ensure the same scripts don't get added to the HTML twice
   shiny::singleton(
-    shiny::tags$head(
+    insertHead(
       # add the message handlers
       shiny::tags$script(shiny::HTML(controllers)),
       # add the actual javascript code
@@ -39,14 +41,29 @@ setupJS <- function(jsFuncs, script, text, ...) {
   )
 }
 
+# insert content into the <head> tag of the document if this is a proper HTML
+# Shiny app, but if it's inside an interactive Rmarkdown document then don't
+# use <head> as it won't work
+insertHead <- function(...) {
+  if (is.null(.globals$rmd) || .globals$rmd) {
+    shiny::tagList(...)
+  } else {
+    shiny::tags$head(...)
+  }
+}
+
+# include a JavaScript script
 shinyjsInlcudeScript <- function(script) {
   if (missing(script) || is.null(script)) {
     return(NULL)
   } else {
-    shiny::includeScript(script)
+    resourcePrefix <- sprintf("shinyjs-%s", digest::digest(script, algo = "md5"))
+    shiny::addResourcePath(resourcePrefix, dirname(script))
+    shiny::tags$script(src = file.path(resourcePrefix, basename(script)))
   }
 }
 
+# include a JavaScript string
 shinyjsInlineScript <- function(text) {
   if (missing(text) || is.null(text)) {
     return(NULL)
